@@ -23,7 +23,7 @@ class HttpSuccess(BaseModel):
 
 
 class HttpError(BaseModel):
-    statusCode: int
+    status_code: int
     error: CustomError
 
 
